// generated from rosidl_adapter/resource/msg.idl.em
// with input from controller_manager_msgs/msg/ControllerManagerActivity.msg
// generated code does not contain a copyright notice

#include "controller_manager_msgs/msg/NamedLifecycleState.idl"
#include "std_msgs/msg/Header.idl"

module controller_manager_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This message is used to provide the activity within the controller manager regarding the change in state of controllers and hardware interfaces")
    struct ControllerManagerActivity {
      @verbatim (language="comment", text=
        "The header is used to provide timestamp information")
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "The current state of the controllers")
      sequence<controller_manager_msgs::msg::NamedLifecycleState> controllers;

      @verbatim (language="comment", text=
        "The current state of the hardware components")
      sequence<controller_manager_msgs::msg::NamedLifecycleState> hardware_components;
    };
  };
};
