// generated from rosidl_adapter/resource/msg.idl.em
// with input from controller_manager_msgs/msg/ChainConnection.msg
// generated code does not contain a copyright notice


module controller_manager_msgs {
  module msg {
    struct ChainConnection {
      @verbatim (language="comment", text=
        "name of controller exporting reference_interfaces")
      string name;

      @verbatim (language="comment", text=
        "list of reference exported by controller")
      sequence<string> reference_interfaces;
    };
  };
};
