// generated from rosidl_generator_c/resource/idl.h.em
// with input from controller_manager_msgs:msg/ControllerManagerActivity.idl
// generated code does not contain a copyright notice

#ifndef CONTROLLER_MANAGER_MSGS__MSG__CONTROLLER_MANAGER_ACTIVITY_H_
#define CONTROLLER_MANAGER_MSGS__MSG__CONTROLLER_MANAGER_ACTIVITY_H_

#include "controller_manager_msgs/msg/detail/controller_manager_activity__struct.h"
#include "controller_manager_msgs/msg/detail/controller_manager_activity__functions.h"
#include "controller_manager_msgs/msg/detail/controller_manager_activity__type_support.h"

#endif  // CONTROLLER_MANAGER_MSGS__MSG__CONTROLLER_MANAGER_ACTIVITY_H_
