// generated from rosidl_generator_py/resource/_idl_support.c.em
// with input from controller_manager_msgs:msg/ControllerManagerActivity.idl
// generated code does not contain a copyright notice
#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
#include <Python.h>
#include <stdbool.h>
#ifndef _WIN32
# pragma GCC diagnostic push
# pragma GCC diagnostic ignored "-Wunused-function"
#endif
#include "numpy/ndarrayobject.h"
#ifndef _WIN32
# pragma GCC diagnostic pop
#endif
#include "rosidl_runtime_c/visibility_control.h"
#include "controller_manager_msgs/msg/detail/controller_manager_activity__struct.h"
#include "controller_manager_msgs/msg/detail/controller_manager_activity__functions.h"

#include "rosidl_runtime_c/primitives_sequence.h"
#include "rosidl_runtime_c/primitives_sequence_functions.h"

// Nested array functions includes
#include "controller_manager_msgs/msg/detail/named_lifecycle_state__functions.h"
// end nested array functions include
ROSIDL_GENERATOR_C_IMPORT
bool std_msgs__msg__header__convert_from_py(PyObject * _pymsg, void * _ros_message);
ROSIDL_GENERATOR_C_IMPORT
PyObject * std_msgs__msg__header__convert_to_py(void * raw_ros_message);
bool controller_manager_msgs__msg__named_lifecycle_state__convert_from_py(PyObject * _pymsg, void * _ros_message);
PyObject * controller_manager_msgs__msg__named_lifecycle_state__convert_to_py(void * raw_ros_message);
bool controller_manager_msgs__msg__named_lifecycle_state__convert_from_py(PyObject * _pymsg, void * _ros_message);
PyObject * controller_manager_msgs__msg__named_lifecycle_state__convert_to_py(void * raw_ros_message);

ROSIDL_GENERATOR_C_EXPORT
bool controller_manager_msgs__msg__controller_manager_activity__convert_from_py(PyObject * _pymsg, void * _ros_message)
{
  // check that the passed message is of the expected Python class
  {
    char full_classname_dest[83];
    {
      char * class_name = NULL;
      char * module_name = NULL;
      {
        PyObject * class_attr = PyObject_GetAttrString(_pymsg, "__class__");
        if (class_attr) {
          PyObject * name_attr = PyObject_GetAttrString(class_attr, "__name__");
          if (name_attr) {
            class_name = (char *)PyUnicode_1BYTE_DATA(name_attr);
            Py_DECREF(name_attr);
          }
          PyObject * module_attr = PyObject_GetAttrString(class_attr, "__module__");
          if (module_attr) {
            module_name = (char *)PyUnicode_1BYTE_DATA(module_attr);
            Py_DECREF(module_attr);
          }
          Py_DECREF(class_attr);
        }
      }
      if (!class_name || !module_name) {
        return false;
      }
      snprintf(full_classname_dest, sizeof(full_classname_dest), "%s.%s", module_name, class_name);
    }
    assert(strncmp("controller_manager_msgs.msg._controller_manager_activity.ControllerManagerActivity", full_classname_dest, 82) == 0);
  }
  controller_manager_msgs__msg__ControllerManagerActivity * ros_message = _ros_message;
  {  // header
    PyObject * field = PyObject_GetAttrString(_pymsg, "header");
    if (!field) {
      return false;
    }
    if (!std_msgs__msg__header__convert_from_py(field, &ros_message->header)) {
      Py_DECREF(field);
      return false;
    }
    Py_DECREF(field);
  }
  {  // controllers
    PyObject * field = PyObject_GetAttrString(_pymsg, "controllers");
    if (!field) {
      return false;
    }
    PyObject * seq_field = PySequence_Fast(field, "expected a sequence in 'controllers'");
    if (!seq_field) {
      Py_DECREF(field);
      return false;
    }
    Py_ssize_t size = PySequence_Size(field);
    if (-1 == size) {
      Py_DECREF(seq_field);
      Py_DECREF(field);
      return false;
    }
    if (!controller_manager_msgs__msg__NamedLifecycleState__Sequence__init(&(ros_message->controllers), size)) {
      PyErr_SetString(PyExc_RuntimeError, "unable to create controller_manager_msgs__msg__NamedLifecycleState__Sequence ros_message");
      Py_DECREF(seq_field);
      Py_DECREF(field);
      return false;
    }
    controller_manager_msgs__msg__NamedLifecycleState * dest = ros_message->controllers.data;
    for (Py_ssize_t i = 0; i < size; ++i) {
      if (!controller_manager_msgs__msg__named_lifecycle_state__convert_from_py(PySequence_Fast_GET_ITEM(seq_field, i), &dest[i])) {
        Py_DECREF(seq_field);
        Py_DECREF(field);
        return false;
      }
    }
    Py_DECREF(seq_field);
    Py_DECREF(field);
  }
  {  // hardware_components
    PyObject * field = PyObject_GetAttrString(_pymsg, "hardware_components");
    if (!field) {
      return false;
    }
    PyObject * seq_field = PySequence_Fast(field, "expected a sequence in 'hardware_components'");
    if (!seq_field) {
      Py_DECREF(field);
      return false;
    }
    Py_ssize_t size = PySequence_Size(field);
    if (-1 == size) {
      Py_DECREF(seq_field);
      Py_DECREF(field);
      return false;
    }
    if (!controller_manager_msgs__msg__NamedLifecycleState__Sequence__init(&(ros_message->hardware_components), size)) {
      PyErr_SetString(PyExc_RuntimeError, "unable to create controller_manager_msgs__msg__NamedLifecycleState__Sequence ros_message");
      Py_DECREF(seq_field);
      Py_DECREF(field);
      return false;
    }
    controller_manager_msgs__msg__NamedLifecycleState * dest = ros_message->hardware_components.data;
    for (Py_ssize_t i = 0; i < size; ++i) {
      if (!controller_manager_msgs__msg__named_lifecycle_state__convert_from_py(PySequence_Fast_GET_ITEM(seq_field, i), &dest[i])) {
        Py_DECREF(seq_field);
        Py_DECREF(field);
        return false;
      }
    }
    Py_DECREF(seq_field);
    Py_DECREF(field);
  }

  return true;
}

ROSIDL_GENERATOR_C_EXPORT
PyObject * controller_manager_msgs__msg__controller_manager_activity__convert_to_py(void * raw_ros_message)
{
  /* NOTE(esteve): Call constructor of ControllerManagerActivity */
  PyObject * _pymessage = NULL;
  {
    PyObject * pymessage_module = PyImport_ImportModule("controller_manager_msgs.msg._controller_manager_activity");
    assert(pymessage_module);
    PyObject * pymessage_class = PyObject_GetAttrString(pymessage_module, "ControllerManagerActivity");
    assert(pymessage_class);
    Py_DECREF(pymessage_module);
    _pymessage = PyObject_CallObject(pymessage_class, NULL);
    Py_DECREF(pymessage_class);
    if (!_pymessage) {
      return NULL;
    }
  }
  controller_manager_msgs__msg__ControllerManagerActivity * ros_message = (controller_manager_msgs__msg__ControllerManagerActivity *)raw_ros_message;
  {  // header
    PyObject * field = NULL;
    field = std_msgs__msg__header__convert_to_py(&ros_message->header);
    if (!field) {
      return NULL;
    }
    {
      int rc = PyObject_SetAttrString(_pymessage, "header", field);
      Py_DECREF(field);
      if (rc) {
        return NULL;
      }
    }
  }
  {  // controllers
    PyObject * field = NULL;
    size_t size = ros_message->controllers.size;
    field = PyList_New(size);
    if (!field) {
      return NULL;
    }
    controller_manager_msgs__msg__NamedLifecycleState * item;
    for (size_t i = 0; i < size; ++i) {
      item = &(ros_message->controllers.data[i]);
      PyObject * pyitem = controller_manager_msgs__msg__named_lifecycle_state__convert_to_py(item);
      if (!pyitem) {
        Py_DECREF(field);
        return NULL;
      }
      int rc = PyList_SetItem(field, i, pyitem);
      (void)rc;
      assert(rc == 0);
    }
    assert(PySequence_Check(field));
    {
      int rc = PyObject_SetAttrString(_pymessage, "controllers", field);
      Py_DECREF(field);
      if (rc) {
        return NULL;
      }
    }
  }
  {  // hardware_components
    PyObject * field = NULL;
    size_t size = ros_message->hardware_components.size;
    field = PyList_New(size);
    if (!field) {
      return NULL;
    }
    controller_manager_msgs__msg__NamedLifecycleState * item;
    for (size_t i = 0; i < size; ++i) {
      item = &(ros_message->hardware_components.data[i]);
      PyObject * pyitem = controller_manager_msgs__msg__named_lifecycle_state__convert_to_py(item);
      if (!pyitem) {
        Py_DECREF(field);
        return NULL;
      }
      int rc = PyList_SetItem(field, i, pyitem);
      (void)rc;
      assert(rc == 0);
    }
    assert(PySequence_Check(field));
    {
      int rc = PyObject_SetAttrString(_pymessage, "hardware_components", field);
      Py_DECREF(field);
      if (rc) {
        return NULL;
      }
    }
  }

  // ownership of _pymessage is transferred to the caller
  return _pymessage;
}
